@@ -125,10 +125,7 @@ impl HlsSink3 {
 
         let (target_duration, playlist_type) = {
             let settings = self.settings.lock().unwrap();
-            (
-                settings.target_duration as f32,
-                settings.playlist_type.clone(),
-            )
+            (settings.target_duration as f32, settings.playlist_type)
         };
 
         let mut state = self.state.lock().unwrap();
@@ -577,7 +574,7 @@ impl ObjectImpl for HlsSink3 {
                         .expect("playlist-stream signal arg");
                     let playlist_location =
                         args[1].get::<String>().expect("playlist-stream signal arg");
-                    let hlssink3 = HlsSink3::from_instance(&element);
+                    let hlssink3 = element.imp();
 
                     Some(
                         hlssink3
@@ -603,7 +600,7 @@ impl ObjectImpl for HlsSink3 {
                         .expect("fragment-stream signal arg");
                     let fragment_location =
                         args[1].get::<String>().expect("fragment-stream signal arg");
-                    let hlssink3 = HlsSink3::from_instance(&element);
+                    let hlssink3 = element.imp();
 
                     Some(
                         hlssink3
@@ -626,7 +623,7 @@ impl ObjectImpl for HlsSink3 {
                 .class_handler(|_, args| {
                     let element = args[0].get::<super::HlsSink3>().expect("signal arg");
                     let fragment_location = args[1].get::<String>().expect("signal arg");
-                    let hlssink3 = HlsSink3::from_instance(&element);
+                    let hlssink3 = element.imp();
 
                     hlssink3.delete_fragment(&element, &fragment_location);
                     Some(true.to_value())
@@ -676,7 +673,7 @@ impl ObjectImpl for HlsSink3 {
                     Some(element) => element,
                     None => return Some(None::<String>.to_value()),
                 };
-                let hlssink3 = HlsSink3::from_instance(&element);
+                let hlssink3 = element.imp();
 
                 let fragment_id = args[1].get::<u32>().unwrap();
 
